@@ -10,58 +10,11 @@ commonmeta-py is a Python library to convert scholarly metadata
 """
 
 __title__ = "commonmeta-py"
-__version__ = "0.98"
+__version__ = "0.118"
 __author__ = "Martin Fenner"
 __license__ = "MIT"
 
 # ruff: noqa: F401
-from .metadata import Metadata, MetadataList
-from .readers import (
-    cff_reader,
-    codemeta_reader,
-    crossref_reader,
-    crossref_xml_reader,
-    datacite_reader,
-    datacite_xml_reader,
-    inveniordm_reader,
-    json_feed_reader,
-    kbase_reader,
-    ris_reader,
-    schema_org_reader,
-)
-from .writers import (
-    bibtex_writer,
-    citation_writer,
-    commonmeta_writer,
-    csl_writer,
-    datacite_writer,
-    ris_writer,
-    schema_org_writer,
-)
-from .utils import (
-    dict_to_spdx,
-    extract_url,
-    extract_urls,
-    extract_curie,
-    from_csl,
-    from_json_feed,
-    from_schema_org,
-    get_language,
-    issn_as_url,
-    name_to_fos,
-    normalize_cc_url,
-    normalize_id,
-    normalize_ids,
-    normalize_orcid,
-    normalize_url,
-    normalize_ror,
-    pages_as_string,
-    replace_curie,
-    to_csl,
-    validate_orcid,
-    validate_ror,
-    validate_url,
-)
 from .author_utils import (
     authors_as_string,
     cleanup_author,
@@ -71,12 +24,12 @@ from .author_utils import (
     is_personal_name,
 )
 from .base_utils import (
-    wrap,
-    unwrap,
     compact,
-    presence,
     parse_attributes,
+    presence,
     sanitize,
+    unwrap,
+    wrap,
 )
 from .date_utils import (
     get_date_from_crossref_parts,
@@ -89,15 +42,72 @@ from .date_utils import (
 from .doi_utils import (
     crossref_api_url,
     crossref_xml_api_url,
-    doi_from_url,
-    doi_as_url,
-    doi_resolver,
-    decode_doi,
-    encode_doi,
     datacite_api_url,
+    decode_doi,
+    doi_as_url,
+    doi_from_url,
+    doi_resolver,
+    encode_doi,
     get_doi_ra,
+    is_rogue_scholar_doi,
     normalize_doi,
     validate_doi,
     validate_prefix,
-    is_rogue_scholar_doi,
+)
+from .file_utils import (
+    download_file,
+    read_file,
+    read_gz_file,
+    read_zip_file,
+    uncompress_content,
+    unzip_content,
+)
+from .metadata import Metadata, MetadataList
+from .readers import (
+    cff_reader,
+    codemeta_reader,
+    crossref_reader,
+    crossref_xml_reader,
+    datacite_reader,
+    datacite_xml_reader,
+    inveniordm_reader,
+    jsonfeed_reader,
+    kbase_reader,
+    openalex_reader,
+    ris_reader,
+    schema_org_reader,
+)
+from .utils import (
+    dict_to_spdx,
+    extract_curie,
+    extract_url,
+    extract_urls,
+    from_csl,
+    from_jsonfeed,
+    from_schema_org,
+    get_language,
+    issn_as_url,
+    name_to_fos,
+    normalize_cc_url,
+    normalize_id,
+    normalize_ids,
+    normalize_orcid,
+    normalize_ror,
+    normalize_url,
+    pages_as_string,
+    replace_curie,
+    to_csl,
+    validate_orcid,
+    validate_ror,
+    validate_url,
+)
+from .writers import (
+    bibtex_writer,
+    citation_writer,
+    commonmeta_writer,
+    crossref_xml_writer,
+    csl_writer,
+    datacite_writer,
+    ris_writer,
+    schema_org_writer,
 )
