@@ -2,9 +2,10 @@
 
 import re
 from typing import Optional
-import httpx
-from furl import furl
+
 import base32_lib as base32
+import requests
+from furl import furl
 
 from .base_utils import compact
 
@@ -71,8 +72,12 @@ def doi_from_url(url: Optional[str]) -> Optional[str]:
             f.path.segments[-1] in ["fetchobject.action"]
             and f.args.get("uri", None) is not None
         ):
-            f.path = f.args.get("uri")
-    path = str(f.path)
+            uri = f.args.get("uri")
+            if uri is not None:
+                f.path.segments.clear()
+                f.path.segments.append(uri)
+
+    path = str(f.path).replace("%2F", "/")
     match = re.search(
         r"(10\.\d{4,5}/.+)\Z",
         path,
@@ -86,9 +91,12 @@ def short_doi_as_doi(doi: Optional[str]) -> Optional[str]:
     """Resolve a short DOI"""
     if doi is None:
         return None
-    response = httpx.head(doi_as_url(doi), timeout=10)
+    doi_url = doi_as_url(doi)
+    if doi_url is None:
+        return None
+    response = requests.head(doi_url, timeout=10)
     if response.status_code != 301:
-        return doi_as_url(doi)
+        return doi_url
     return response.headers.get("Location")
 
 
@@ -106,7 +114,10 @@ def normalize_doi(doi: Optional[str], **kwargs) -> Optional[str]:
     doi_str = validate_doi(doi)
     if not doi_str:
         return None
-    return doi_resolver(doi, **kwargs) + doi_str.lower()
+    resolver = doi_resolver(doi, **kwargs)
+    if resolver is None:
+        return None
+    return resolver + doi_str.lower()
 
 
 def doi_resolver(doi, **kwargs):
@@ -126,7 +137,7 @@ def get_doi_ra(doi) -> Optional[str]:
     prefix = validate_prefix(doi)
     if prefix is None:
         return None
-    response = httpx.get("https://doi.org/ra/" + prefix, timeout=10)
+    response = requests.get("https://doi.org/ra/" + prefix, timeout=10)
     if response.status_code != 200:
         return None
     return response.json()[0].get("RA", None)
@@ -144,13 +155,14 @@ def encode_doi(prefix, number: Optional[int] = None, checksum: bool = True) -> s
 def decode_doi(doi: str, checksum: bool = True) -> int:
     """Decode a DOI to a number"""
     try:
-        doi = validate_doi(doi)
-        if doi is None:
+        validated_doi = validate_doi(doi)
+        if validated_doi is None:
             return 0
-        suffix = doi.split("/", maxsplit=1)[1]
+        suffix = validated_doi.split("/", maxsplit=1)[1]
         if checksum:
             number = base32.decode(suffix, checksum=True)
-        number = base32.decode(suffix)
+        else:
+            number = base32.decode(suffix)
         return number
     except ValueError:
         return 0
@@ -158,7 +170,7 @@ def decode_doi(doi: str, checksum: bool = True) -> int:
 
 def get_crossref_member(member_id) -> Optional[dict]:
     """Return the Crossref member for a given member_id"""
-    response = httpx.get("https://api.crossref.org/members/" + member_id, timeout=10)
+    response = requests.get("https://api.crossref.org/members/" + member_id, timeout=10)
     if response.status_code != 200:
         return None
     data = response.json().get("message", None)
@@ -183,6 +195,9 @@ def crossref_api_query_url(query: dict) -> str:
     rows = min(int(query.get("rows", 20)), 1000)
     queries = []
     filters = []
+    _query = None
+    _filter = None
+
     if query.get("query", None) is not None:
         queries += [query.get("query")]
     for key, value in query.items():
@@ -193,7 +208,8 @@ def crossref_api_query_url(query: dict) -> str:
             "query.container-title",
         ]:
             queries += [f"{key}:{value}"]
-        _query = ",".join(queries) if len(queries) > 0 else None
+    if queries:
+        _query = ",".join(queries)
 
     for key, value in query.items():
         if key in [
@@ -207,8 +223,10 @@ def crossref_api_query_url(query: dict) -> str:
             "has-license",
         ]:
             filters += [f"{key}:{value}"]
-        _filter = ",".join(filters) if len(filters) > 0 else None
-    f.args = compact({"rows": rows, "query": _query, "filter": _filter})
+    if filters:
+        _filter = ",".join(filters)
+
+    f.args.update(compact({"rows": rows, "query": _query, "filter": _filter}))
 
     return f.url
 
@@ -284,18 +302,101 @@ def datacite_api_sample_url(number: int = 1, **kwargs) -> str:
     return f"https://api.datacite.org/dois?random=true&page[size]={number}"
 
 
-def is_rogue_scholar_doi(doi: str) -> bool:
-    """Return True if DOI is from Rogue Scholar"""
-    prefix = validate_prefix(doi)
-    return prefix in [
-        "10.34732",  # not managed by Front Matter
+def is_rogue_scholar_doi(doi: str, ra: str = "crossref") -> bool:
+    """Check if a DOI is from Rogue Scholar with specific registration agency"""
+    rogue_scholar_crossref_prefixes = [
+        "10.13003",
         "10.53731",
         "10.54900",
-        "10.57689",  # not managed by Front Matter
-        "10.58079",  # not managed by Front Matter
+        "10.57689",
+        "10.59347",
         "10.59348",
         "10.59349",
         "10.59350",
         "10.63485",
         "10.64000",
     ]
+    rogue_scholar_datacite_prefixes = [
+        "10.5438",
+        "10.34732",  # not managed by Front Matter
+        "10.57689",  # not managed by Front Matter
+        "10.58079",  # not managed by Front Matter
+        "10.60804",
+        "10.71938",  # not managed by Front Matter
+        # "10.83132",
+    ]
+
+    prefix = validate_prefix(doi)
+    if not prefix:
+        return False
+
+    is_crossref = prefix in rogue_scholar_crossref_prefixes
+    is_datacite = prefix in rogue_scholar_datacite_prefixes
+
+    if ra == "crossref":
+        return is_crossref
+    elif ra == "datacite":
+        return is_datacite
+    return is_crossref or is_datacite
+
+
+def generate_wordpress_doi(prefix: str, slug: str, guid: str) -> str:
+    """Generate a DOI from a WordPress GUID and slug"""
+    import re
+
+    if not prefix or not guid:
+        return ""
+
+    pattern = re.compile(r"p=(\d+)$")
+    matched = pattern.search(guid)
+
+    if not matched:
+        return ""
+
+    doi = f"https://doi.org/{prefix}/{slug}.{matched.group(1)}"
+    return doi
+
+
+def generate_doi_from_guid(prefix: str, guid: str) -> str:
+    """Validates a GUID that is a DOI"""
+    import base32_lib as base32
+
+    if not prefix:
+        return ""
+
+    doi = normalize_doi(guid)
+    if not doi:
+        return ""
+
+    p = validate_prefix(doi)
+    if not p or p != prefix:
+        return ""
+
+    suffix = doi.split("/")[-1]
+
+    try:
+        number = base32.decode(suffix, checksum=True)
+        if number != 0:
+            return doi
+    except (ValueError, IndexError):
+        pass
+
+    return ""
+
+
+def generate_substack_doi(prefix: str, guid: str) -> str:
+    """Generate a DOI from a Substack GUID"""
+    import base32_lib as base32
+
+    if not prefix or not guid:
+        return ""
+
+    try:
+        i = int(guid)
+    except ValueError:
+        return ""
+
+    # encode the number using base32 with length=4, split_every=8, and checksum=True
+    suffix = base32.encode(i, length=4, split_every=8, checksum=True)
+    doi = f"https://doi.org/{prefix}/{suffix}"
+    return doi
