@@ -1,29 +1,31 @@
 """codemeta reader for commonmeta-py"""
-from typing import Optional
+
 from collections import defaultdict
+from typing import Optional
+
 import requests
 
+from ..author_utils import get_authors
+from ..base_utils import compact, presence, sanitize, wrap
+from ..constants import (
+    SO_TO_CM_TRANSLATIONS,
+    Commonmeta,
+)
 from ..utils import (
-    normalize_id,
-    from_schema_org_creators,
-    name_to_fos,
     dict_to_spdx,
+    doi_from_url,
+    from_schema_org_creators,
     github_as_codemeta_url,
     github_as_repo_url,
-    doi_from_url,
-)
-from ..base_utils import wrap, presence, compact, sanitize
-from ..author_utils import get_authors
-from ..constants import (
-    Commonmeta,
-    SO_TO_CM_TRANSLATIONS,
+    name_to_fos,
+    normalize_id,
 )
 
 
 def get_codemeta(pid: str, **kwargs) -> dict:
     """get_codemeta"""
     url = str(github_as_codemeta_url(pid))
-    response = requests.get(url, kwargs, timeout=10)
+    response = requests.get(url, timeout=10, **kwargs)
     if response.status_code != 200:
         return {"state": "not_found"}
     data = response.json()
@@ -43,9 +45,9 @@ def read_codemeta(data: Optional[dict], **kwargs) -> Commonmeta:
     # ActiveSupport: : HashWithIndifferentAccess.new(options.except(: doi, : id, : url,
     # : sandbox, : validate, : ra)
 
-    id_ = normalize_id(meta.get("id", None) or meta.get("identifier", None))
+    _id = normalize_id(meta.get("id", None) or meta.get("identifier", None))
     # id = normalize_id(options[:doi] | | meta.get('@id', None) | | meta.get('identifier', None))
-    type_ = SO_TO_CM_TRANSLATIONS.get(meta.get("@type", 'Software'))
+    _type = SO_TO_CM_TRANSLATIONS.get(meta.get("@type", "Software"))
     # identifiers = Array.wrap(meta.get('identifier', None)).map do | r|
     #   r = normalize_id(r) if r.is_a?(String)
     #   if r.is_a?(String) & & URI(r) != 'doi.org'
@@ -58,13 +60,14 @@ def read_codemeta(data: Optional[dict], **kwargs) -> Commonmeta:
 
     has_agents = meta.get("agents", None)
     authors = meta.get("authors", None) if has_agents is None else has_agents
-    creators = get_authors(from_schema_org_creators(wrap(authors)))
-    contributors = get_authors(from_schema_org_creators(wrap(meta.get("editor", None))))
-    
+    contributors = get_authors(from_schema_org_creators(wrap(authors)))
+    contrib = get_authors(from_schema_org_creators(wrap(meta.get("editor", None))))
+    if contrib:
+        contributors += contrib
     date: dict = defaultdict(list)
-    date['created'] = meta.get("dateCreated", None)
-    date['published'] = meta.get("datePublished", None)
-    date['updated'] = meta.get("dateModified", None)
+    date["created"] = meta.get("dateCreated", None)
+    date["published"] = meta.get("datePublished", None)
+    date["updated"] = meta.get("dateModified", None)
 
     publisher = {"name": meta.get("publisher", None)}
 
@@ -72,7 +75,7 @@ def read_codemeta(data: Optional[dict], **kwargs) -> Commonmeta:
         descriptions = [
             {
                 "description": sanitize(str(meta.get("description"))),
-                "descriptionType": "Abstract",
+                "type": "Abstract",
             }
         ]
     else:
@@ -89,18 +92,17 @@ def read_codemeta(data: Optional[dict], **kwargs) -> Commonmeta:
     license_ = meta.get("licenseId", None)
     if license_:
         license_ = dict_to_spdx({"id": meta.get("licenseId")})
-    
-    provider = "DataCite" if doi_from_url(id_) else "GitHub"
+
+    provider = "DataCite" if doi_from_url(_id) else "GitHub"
     state = "findable" if meta or read_options else "not_found"
 
     return {
-        "id": id_,
-        "type": type_,
+        "id": _id,
+        "type": _type,
         "url": normalize_id(meta.get("codeRepository", None)),
         "identifiers": None,
         "titles": titles,
-        "creators": creators,
-        "contributors": contributors,
+        "contributors": presence(contributors),
         "publisher": publisher,
         "date": compact(date),
         "descriptions": descriptions,
