@@ -1,39 +1,42 @@
 """crossref reader for commonmeta-py"""
 
 from typing import Optional
-import httpx
+from xml.parsers.expat import ExpatError
+
+import requests
 from pydash import py_
+from requests.exceptions import ConnectionError, ReadTimeout
 
-from ..utils import (
-    dict_to_spdx,
-    normalize_cc_url,
-    normalize_url,
-    normalize_doi,
-    normalize_issn,
-    issn_as_url,
-)
-from ..base_utils import wrap, compact, presence, sanitize, parse_attributes
 from ..author_utils import get_authors
-from ..date_utils import get_date_from_date_parts
-from ..doi_utils import (
-    doi_as_url,
-    doi_from_url,
-    crossref_api_url,
-    crossref_api_query_url,
-    crossref_api_sample_url,
-)
+from ..base_utils import compact, parse_attributes, parse_xml, presence, sanitize, wrap
 from ..constants import (
-    CR_TO_CM_TRANSLATIONS,
     CR_TO_CM_CONTAINER_TRANSLATIONS,
+    CR_TO_CM_TRANSLATIONS,
     CROSSREF_CONTAINER_TYPES,
     Commonmeta,
 )
+from ..date_utils import get_date_from_date_parts
+from ..doi_utils import (
+    crossref_api_query_url,
+    crossref_api_sample_url,
+    crossref_api_url,
+    doi_as_url,
+    validate_doi,
+)
+from ..utils import (
+    dict_to_spdx,
+    issn_as_url,
+    normalize_cc_url,
+    normalize_doi,
+    normalize_issn,
+    normalize_url,
+)
 
 
 def get_crossref_list(query: dict, **kwargs) -> list[dict]:
     """get_crossref list from Crossref API."""
     url = crossref_api_query_url(query, **kwargs)
-    response = httpx.get(url, timeout=30, **kwargs)
+    response = requests.get(url, timeout=30, **kwargs)
     if response.status_code != 200:
         return []
     return response.json().get("message", {}).get("items", [])
@@ -41,11 +44,11 @@ def get_crossref_list(query: dict, **kwargs) -> list[dict]:
 
 def get_crossref(pid: str, **kwargs) -> dict:
     """get_crossref"""
-    doi = doi_from_url(pid)
+    doi = validate_doi(pid)
     if doi is None:
         return {"state": "not_found"}
     url = crossref_api_url(doi)
-    response = httpx.get(url, timeout=10, **kwargs)
+    response = requests.get(url, timeout=10, **kwargs)
     if response.status_code != 200:
         return {"state": "not_found"}
     return response.json().get("message", {}) | {"via": "crossref"}
@@ -64,6 +67,7 @@ def read_crossref(data: Optional[dict], **kwargs) -> Commonmeta:
     doi = meta.get("DOI", None)
     _id = doi_as_url(doi)
     _type = CR_TO_CM_TRANSLATIONS.get(meta.get("type", None)) or "Other"
+    additional_type = meta.get("subtype", None)
 
     archive_locations = wrap(meta.get("archive", None))
 
@@ -118,13 +122,7 @@ def read_crossref(data: Optional[dict], **kwargs) -> Commonmeta:
         relations = py_.uniq(relations)
     references = py_.uniq([get_reference(i) for i in wrap(meta.get("reference", None))])
     funding_references = from_crossref_funding(wrap(meta.get("funder", None)))
-
-    description = meta.get("abstract", None)
-    if description is not None:
-        descriptions = [{"description": sanitize(description), "type": "Abstract"}]
-    else:
-        descriptions = None
-
+    descriptions = get_abstract(meta)
     subjects = py_.uniq(
         [
             {"subject": i}
@@ -144,7 +142,7 @@ def read_crossref(data: Optional[dict], **kwargs) -> Commonmeta:
         "id": _id,
         "type": _type,
         # recommended and optional properties
-        "additionalType": None,
+        "additionalType": additional_type,
         "archiveLocations": presence(archive_locations),
         "container": presence(container),
         "contributors": presence(contributors),
@@ -199,6 +197,23 @@ def get_titles(meta):
     )
 
 
+def get_abstract(meta: dict) -> Optional[str]:
+    """Get abstract from Crossref metadata."""
+    abstract = meta.get("abstract", None)
+    if abstract is None:
+        return None
+
+    try:
+        # Parse the abstract XML if it is JATS formatted
+        description_dct = parse_xml(abstract, xml_attribs=True)
+        description = py_.get(description_dct, "jats:p")
+        if description is None:
+            description = abstract
+        return [{"description": sanitize(description), "type": "Abstract"}]
+    except (TypeError, ExpatError):
+        return [{"description": sanitize(abstract), "type": "Abstract"}]
+
+
 def get_reference(reference: Optional[dict]) -> Optional[dict]:
     """Get reference from Crossref reference"""
     if reference is None or not isinstance(reference, dict):
@@ -339,7 +354,7 @@ def get_container(meta: dict, issn: str) -> dict:
     )
     isbn = isbn["value"] if isbn else None
     container_title = parse_attributes(meta.get("container-title", None), first=True)
-    if not container_title and container_type in ["Periodical"]:
+    if not container_title:
         container_title = py_.get(meta, "institution.0.name")
     volume = meta.get("volume", None)
     issue = py_.get(meta, "journal-issue.issue")
@@ -401,11 +416,11 @@ def get_random_crossref_id(number: int = 1, **kwargs) -> list:
     number = 20 if number > 20 else number
     url = crossref_api_sample_url(number, **kwargs)
     try:
-        response = httpx.get(url, timeout=10)
+        response = requests.get(url, timeout=10)
         if response.status_code != 200:
             return []
 
         items = py_.get(response.json(), "message.items")
         return [i.get("DOI") for i in items]
-    except (httpx.ReadTimeout, httpx.ConnectError):
+    except (ReadTimeout, ConnectionError):
         return []
