@@ -1,26 +1,26 @@
 """InvenioRDM reader for Commonmeta"""
 
-import httpx
-from pydash import py_
+import requests
 from furl import furl
+from pydash import py_
 
-from ..utils import (
-    normalize_url,
-    normalize_doi,
-    dict_to_spdx,
-    name_to_fos,
-    from_inveniordm,
-    get_language,
-    validate_ror,
-)
-from ..base_utils import compact, wrap, presence, sanitize
 from ..author_utils import get_authors
+from ..base_utils import compact, presence, sanitize, wrap
+from ..constants import (
+    COMMONMETA_RELATION_TYPES,
+    INVENIORDM_TO_CM_TRANSLATIONS,
+    Commonmeta,
+)
 from ..date_utils import strip_milliseconds
 from ..doi_utils import doi_as_url, doi_from_url
-from ..constants import (
-    INVENIORDM_TO_CM_TRANSLATIONS,
-    COMMONMETA_RELATION_TYPES,
-    Commonmeta,
+from ..utils import (
+    dict_to_spdx,
+    from_inveniordm,
+    get_language,
+    name_to_fos,
+    normalize_doi,
+    normalize_url,
+    validate_ror,
 )
 
 
@@ -29,7 +29,7 @@ def get_inveniordm(pid: str, **kwargs) -> dict:
     if pid is None:
         return {"state": "not_found"}
     url = normalize_url(pid)
-    response = httpx.get(url, timeout=10, follow_redirects=True, **kwargs)
+    response = requests.get(url, timeout=10, allow_redirects=True, **kwargs)
     if response.status_code != 200:
         return {"state": "not_found"}
     return response.json()
@@ -63,7 +63,6 @@ def read_inveniordm(data: dict, **kwargs) -> Commonmeta:
 
     title = py_.get(meta, "metadata.title")
     titles = [{"title": sanitize(title)}] if title else None
-    additional_titles = py_.get(meta, "metadata.additional_titles")
     # if additional_titles:
     #     titles += [{"title": sanitize("bla")} for i in wrap(additional_titles)]
 
@@ -188,17 +187,22 @@ def get_funding_references(funding_references: list) -> list:
     def map_funding(funding: dict) -> dict:
         """map_funding"""
 
-        return compact({
-            "funderName": py_.get(funding, "funder.name"),
-            "funderIdentifier": py_.get(funding, "funder.id"),
-            "funderIdentifierType": "ROR" if validate_ror(py_.get(funding, "funder.id")) else None,
-            "awardTitle": py_.get(funding, "award.title.en"),
-            "awardNumber": py_.get(funding, "award.number"),
-            "awardUri": py_.get(funding, "award.identifiers[0].identifier"),
-        })
-    
+        return compact(
+            {
+                "funderName": py_.get(funding, "funder.name"),
+                "funderIdentifier": py_.get(funding, "funder.id"),
+                "funderIdentifierType": "ROR"
+                if validate_ror(py_.get(funding, "funder.id"))
+                else None,
+                "awardTitle": py_.get(funding, "award.title.en"),
+                "awardNumber": py_.get(funding, "award.number"),
+                "awardUri": py_.get(funding, "award.identifiers[0].identifier"),
+            }
+        )
+
     return [map_funding(i) for i in funding_references]
 
+
 def get_file(file: dict) -> str:
     """get_file"""
     _type = file.get("type", None)
