@@ -1,22 +1,22 @@
 """Utils module for commonmeta-py"""
 
 import os
-import orjson as json
 import re
 import time
 from typing import Optional
 from urllib.parse import urlparse
-import yaml
-from furl import furl
+
 import bibtexparser
-from bs4 import BeautifulSoup
-from pydash import py_
+import orjson as json
 import pycountry
+import yaml
+from bs4 import BeautifulSoup
+from furl import furl
+from pydash import py_
 
-from .base_utils import wrap, compact, parse_attributes
-from .doi_utils import normalize_doi, doi_from_url, get_doi_ra, validate_doi, doi_as_url
+from .base_utils import compact, parse_attributes, wrap
 from .constants import DATACITE_CONTRIBUTOR_TYPES
-
+from .doi_utils import doi_as_url, doi_from_url, get_doi_ra, normalize_doi, validate_doi
 
 NORMALIZED_LICENSES = {
     "https://creativecommons.org/licenses/by/1.0": "https://creativecommons.org/licenses/by/1.0/legalcode",
@@ -144,17 +144,13 @@ def normalize_id(pid: Optional[str], **kwargs) -> Optional[str]:
         return doi
 
     # check for valid HTTP uri and ensure https
-    uri = urlparse(pid)
-    if not uri.netloc or uri.scheme not in ["http", "https"]:
+    f = furl(pid)
+    if not f.host or f.scheme not in ["http", "https"]:
         return None
-    if uri.scheme == "http":
-        pid = pid.replace(HTTP_SCHEME, HTTPS_SCHEME)
+    if f.scheme == "http":
+        f.scheme = "https"
 
-    # remove trailing slash
-    if pid.endswith("/"):
-        pid = pid.strip("/")
-
-    return pid
+    return f.url
 
 
 def normalize_ids(ids: list, relation_type=None) -> list:
@@ -190,8 +186,6 @@ def normalize_url(
     if url is None or not isinstance(url, str):
         return None
     url = url.strip()
-    if url.endswith("/"):
-        url = url.strip("/")
     scheme = urlparse(url).scheme
     if not scheme or scheme not in ["http", "https"]:
         return None
@@ -202,55 +196,13 @@ def normalize_url(
     return url
 
 
-# def normalize_url(url: Optional[str], secure=False, fragments=False, lower=False) -> Optional[str]:
-#     """Normalize URL"""
-#     if url is None or not isinstance(url, str):
-#         return None
-#     try:
-#         f = furl(url.strip())
-#         f.path.normalize()
-
-#         # only allow http and https schemes
-#         if f.scheme not in ["http", "https"]:
-#             return None
-#         if secure and f.scheme == "http":
-#             f.set(scheme="https")
-
-#         # remove index.html
-#         if f.path.segments and f.path.segments[-1] in ["index.html"]:
-#             f.path.segments.pop(-1)
-
-#         # remove fragments
-#         if fragments:
-#             f.remove(fragment=True)
-
-#         # remove specific query parameters
-#         f.remove(
-#             [
-#                 "origin",
-#                 "ref",
-#                 "referrer",
-#                 "source",
-#                 "utm_content",
-#                 "utm_medium",
-#                 "utm_campaign",
-#                 "utm_source",
-#             ]
-#         )
-
-#         if lower:
-#             return f.url.lower().strip("/")
-#         return f.url.strip("/")
-#     except ValueError:
-#         print(f"Error normalizing url {url}")
-#         return None
-
-
 def normalize_cc_url(url: Optional[str]):
     """Normalize Creative Commons URL"""
     if url is None or not isinstance(url, str):
         return None
     url = normalize_url(url, secure=True)
+    if url and url.endswith("/"):
+        url = url.strip("/")
     return NORMALIZED_LICENSES.get(url, url)
 
 
@@ -333,6 +285,250 @@ def validate_isni(isni: Optional[str]) -> Optional[str]:
     return isni
 
 
+def validate_mag(mag: Optional[str]) -> Optional[str]:
+    """Validate Microsoft Academic Graph ID (mag)"""
+    if mag is None or not isinstance(mag, str):
+        return None
+    match = re.search(
+        r"\A(\d{4,10})\Z",
+        mag,
+    )
+    if match is None:
+        return None
+    return match.group(1)
+
+
+def validate_openalex(openalex: Optional[str]) -> Optional[str]:
+    """Validate OpenAlex ID"""
+    if openalex is None or not isinstance(openalex, str):
+        return None
+    match = re.search(
+        r"\A(?:(?:http|https)://openalex\.org/)?([AFIPSW]\d{8,10})\Z",
+        openalex,
+    )
+    if match is None:
+        return None
+    return match.group(1)
+
+
+def validate_pmid(pmid: Optional[str]) -> Optional[str]:
+    """Validate PubMed ID (pmid)"""
+    if pmid is None or not isinstance(pmid, str):
+        return None
+    match = re.search(
+        r"\A(?:(?:http|https)://pubmed\.ncbi\.nlm\.nih\.gov/)?(\d{4,8})\Z",
+        pmid,
+    )
+    if match is None:
+        return None
+    return match.group(1)
+
+
+def validate_pmcid(pmcid: Optional[str]) -> Optional[str]:
+    """Validate PubMed Central ID (pmcid)"""
+    if pmcid is None or not isinstance(pmcid, str):
+        return None
+    match = re.search(
+        r"\A(?:(?:http|https)://www\.ncbi\.nlm\.nih\.gov/pmc/articles/)?(\d{4,8})\Z",
+        pmcid,
+    )
+    if match is None:
+        return None
+    return match.group(1)
+
+
+def validate_id(id: Optional[str]) -> tuple[Optional[str], Optional[str]]:
+    """
+    Validate an identifier and return the validated identifier and its type.
+
+    Args:
+        id: The identifier string to validate
+
+    Returns:
+        A tuple containing (validated_id, id_type) or (None, None) if invalid
+    """
+    if id is None:
+        return None, None
+
+    # Check if it's a DOI
+    doi = validate_doi(id)
+    if doi:
+        return doi, "DOI"
+
+    # Check if it's an ORCID
+    orcid = validate_orcid(id)
+    if orcid:
+        return orcid, "ORCID"
+
+    # Check if it's a ROR
+    ror = validate_ror(id)
+    if ror:
+        return ror, "ROR"
+
+    # Check if it's an ISNI
+    isni = validate_isni(id)
+    if isni:
+        return isni, "ISNI"
+
+    # Check if it's an OpenAlex ID
+    openalex = validate_openalex(id)
+    if openalex:
+        return openalex, "OpenAlex"
+
+    # Check if it's a PubMed ID
+    pmid = validate_pmid(id)
+    if pmid:
+        return pmid, "PMID"
+
+    # Check if it's a PubMed Central ID
+    pmcid = validate_pmcid(id)
+    if pmcid:
+        return pmcid, "PMCID"
+
+    # Check if it's a URL
+    url_type = validate_url(id)
+    if url_type:
+        return normalize_url(id), url_type
+
+    # No known valid identifier type was found
+    return None, None
+
+
+def openalex_api_url(id: str, identifier_type: str, **kwargs) -> str:
+    """Return the OpenAlex API URL for a given ID"""
+    if identifier_type == "DOI":
+        return f"https://api.openalex.org/works/{doi_as_url(id)}"
+    if identifier_type == "OpenAlex":
+        return f"https://api.openalex.org/works/{id}"
+    if identifier_type == "PMID":
+        return f"https://api.openalex.org/works?filter=ids.pmid:{id}"
+    if identifier_type == "PMCID":
+        return f"https://api.openalex.org/works?filter=ids.pmcid:{id}"
+
+
+def openalex_api_query_url(query: dict) -> str:
+    """Return the OpenAlex API query URL"""
+    # Define allowed types
+    types = [
+        "article",
+        "book-chapter",
+        "dataset",
+        "preprint",
+        "dissertation",
+        "book",
+        "review",
+        "paratext",
+        "libguides",
+        "letter",
+        "other",
+        "reference-entry",
+        "report",
+        "editorial",
+        "peer-review",
+        "erratum",
+        "standard",
+        "grant",
+        "supplementary-materials",
+        "retraction",
+    ]
+
+    url = "https://api.openalex.org/works"
+    f = furl(url)
+
+    # Handle pagination and sample parameters
+    number = max(1, min(1000, int(query.get("number", query.get("rows", 10)))))
+    page = max(1, int(query.get("page", 1)))
+
+    sample = query.get("sample", False)
+    if sample:
+        f.args["sample"] = str(number)
+    else:
+        f.args["per-page"] = str(number)
+        f.args["page"] = str(page)
+        # Sort results by published date in descending order
+        f.args["sort"] = "publication_date:desc"
+
+    # Build filters
+    filters = []
+    queries = []
+    _query = None
+
+    # Handle query parameters
+    if query.get("query", None) is not None:
+        queries += [query.get("query")]
+    for key, value in query.items():
+        if key in [
+            "query.bibliographic",
+            "query.author",
+            "query.title",
+            "query.container-title",
+        ]:
+            queries += [f"{key}:{value}"]
+    if queries:
+        _query = ",".join(queries)
+        f.args["query"] = _query
+
+    # Member/IDs filter
+    ids = query.get("ids", query.get("member", ""))
+    if ids:
+        filters.append(f"member:{ids}")
+
+    # Type filter
+    type_ = query.get("type_", query.get("type", ""))
+    if type_ and type_ in types:
+        filters.append(f"type:{type_}")
+
+    # ROR filter
+    ror = query.get("ror", "")
+    if ror:
+        r = validate_ror(ror)
+        if r:
+            filters.append(f"authorships.institutions.ror:{r}")
+
+    # ORCID filter
+    orcid = query.get("orcid", "")
+    if orcid:
+        o = validate_orcid(orcid)
+        if o:
+            filters.append(f"authorships.author.orcid:{o}")
+
+    # Year filter
+    year = query.get("year", query.get("publication_year", ""))
+    if year:
+        filters.append(f"publication_year:{year}")
+
+    # Other filters from the original function
+    for key, value in query.items():
+        if key in [
+            "prefix",
+            "has-full-text",
+            "has-funder",
+            "has-license",
+        ]:
+            filters.append(f"{key}:{value}")
+
+    # Boolean filters
+    # if query.get("hasORCID", query.get("has-orcid", False)):
+    #     filters.append("has-orcid:true")
+
+    # if query.get("hasReferences", query.get("has-references", False)):
+    #     filters.append("has-references:true")
+
+    # if query.get("hasAbstract", query.get("has-abstract", False)):
+    #     filters.append("has-abstract:true")
+
+    # Add filters to params if any exist
+    if filters:
+        f.args["filter"] = ",".join(filters)
+
+    return f.url
+
+
+def openalex_api_sample_url(number: int = 1, **kwargs) -> str:
+    """Return the OpenAlex API URL for a sample of dois"""
+    return f"https://api.openalex.org/works?sample={number}"
+
+
 def normalize_isni(isni: Optional[str]) -> Optional[str]:
     """Normalize ISNI"""
     if isni is None or not isinstance(isni, str):
@@ -458,7 +654,7 @@ def dict_to_spdx(dct: dict) -> dict:
     # end
 
 
-def from_json_feed(elements: list) -> list:
+def from_jsonfeed(elements: list) -> list:
     """Convert from JSON Feed elements"""
 
     def format_element(element):
@@ -740,10 +936,24 @@ def find_from_format_by_id(pid: str) -> Optional[str]:
         is not None
     ):
         return "codemeta"
+    if re.match(r"\A(http|https):/(/)?openalex\.org/(.+)\Z", pid) is not None:
+        return "openalex"
+    if (
+        re.match(r"\A(http|https):/(/)?pubmed\.ncbi\.nlm\.nih\.gov/(.+)\Z", pid)
+        is not None
+    ):
+        return "openalex"  # pmid
+    if (
+        re.match(
+            r"\A(http|https):/(/)?www\.ncbi\.nlm\.nih\.gov/pmc/articles/(.+)\Z", pid
+        )
+        is not None
+    ):
+        return "openalex"  # pmcid
     if re.match(r"\A(http|https):/(/)?github\.com/(.+)\Z", pid) is not None:
         return "cff"
     if re.match(r"\Ahttps:/(/)?api\.rogue-scholar\.org/posts/(.+)\Z", pid) is not None:
-        return "json_feed_item"
+        return "jsonfeed"
     if re.match(r"\Ahttps:/(/)(.+)/api/records/(.+)\Z", pid) is not None:
         return "inveniordm"
     return "schema_org"
@@ -771,7 +981,7 @@ def find_from_format_by_dict(dct: dict) -> Optional[str]:
     ]:
         return "codemeta"
     if dct.get("guid", None) is not None:
-        return "json_feed_item"
+        return "jsonfeed"
     if dct.get("schemaVersion", "").startswith("http://datacite.org/schema/kernel"):
         return "datacite"
     if dct.get("source", None) == "Crossref":
@@ -804,7 +1014,7 @@ def find_from_format_by_string(string: str) -> Optional[str]:
         ]:
             return "codemeta"
         if data.get("guid", None) is not None:
-            return "json_feed_item"
+            return "jsonfeed"
         if data.get("schemaVersion", "").startswith(
             "http://datacite.org/schema/kernel"
         ):
@@ -1129,7 +1339,9 @@ def replace_curie(string: Optional[str]) -> Optional[str]:
     if string is None:
         return None
     match = re.sub(
-        r"((?:doi|DOI):\s?([\w.,@?^=%&:\/~+#-]*[\w@?^=%&\/~+#-]))", r'https://doi.org/\2', string
+        r"((?:doi|DOI):\s?([\w.,@?^=%&:\/~+#-]*[\w@?^=%&\/~+#-]))",
+        r"https://doi.org/\2",
+        string,
     )
     if match is None:
         return None
