@@ -1,8 +1,7 @@
 """Commonmeta writer for commonmeta-py"""
 
-import orjson as json
-import orjsonl
 import pydash as py_
+
 from ..base_utils import compact
 
 
@@ -32,12 +31,12 @@ def write_commonmeta(metadata):
             "funding_references": "fundingReferences",
         },
     )
-    return json.dumps(compact(data), option=json.OPT_INDENT_2)
+    return compact(data)
 
 
 def write_commonmeta_list(metalist):
-    """Write commonmeta list. If filename is provided,
-    write to file. Optionally, use JSON Lines format."""
+    """Write commonmeta list. If file is provided,
+    write to file. Supports JSON, JSON Lines and YAML format."""
     if metalist is None:
         return None
 
@@ -47,7 +46,7 @@ def write_commonmeta_list(metalist):
         return compact(item)
 
     items = [format_item(item) for item in metalist.items]
-    output = compact(
+    return compact(
         {
             "id": metalist.id,
             "title": metalist.title,
@@ -55,14 +54,3 @@ def write_commonmeta_list(metalist):
             "items": items,
         }
     )
-
-    if metalist.filename and metalist.filename.rsplit(".", 1)[1] in ["jsonl", "json"]:
-        if metalist.jsonlines:
-            orjsonl.save(metalist.filename, items)
-        else:
-            json_output = json.dumps(output).decode("utf-8")
-            with open(metalist.filename, "w") as file:
-                file.write(json_output)
-        return metalist.filename
-    else:
-        return json.dumps(output).decode("utf-8")
